@@ -709,8 +709,6 @@ void sftpProtocol::openConnection() {
 
   kDebug(KIO_SFTP_DB) << "Trying to authenticate with the server";
 
-  const int method = ssh_auth_list(mSession);
-
   // Try to login without authentication
   rc = ssh_userauth_none(mSession, NULL);
   if (rc == SSH_AUTH_ERROR) {
@@ -719,6 +717,15 @@ void sftpProtocol::openConnection() {
     return;
   }
 
+  // This NEEDS to be called after ssh_userauth_none() !!!
+  int method = ssh_auth_list(mSession);
+  if (rc != SSH_AUTH_SUCCESS && method == 0) {
+      closeConnection();
+      error(KIO::ERR_COULD_NOT_LOGIN, i18n("Authentication failed. The server "
+            "didn't send any authentication methods"));
+      return;
+  }
+
   // Try to authenticate with public key first
   if (rc != SSH_AUTH_SUCCESS && (method & SSH_AUTH_METHOD_PUBLICKEY)) {
     kDebug(KIO_SFTP_DB) << "Trying to authenticate with public key";
@@ -813,6 +820,12 @@ void sftpProtocol::openConnection() {
     }
   }
 
+  // If we're still not authenticated then we need to leave.
+  if (rc != SSH_AUTH_SUCCESS) {
+    error(KIO::ERR_COULD_NOT_LOGIN, i18n("Authentication failed."));
+    return;
+  }
+
   // start sftp session
   kDebug(KIO_SFTP_DB) << "Trying to request the sftp session";
   mSftp = sftp_new(mSession);
